{% load url from future %}
<form action="{% url 'django.contrib.auth.views.login' %}" method="post">{% csrf_token %}
	{{ form.as_p }}
	<input type="submit" name="submit" value="Login">
	<input type="hidden" name="next" value="{{ next }}">
</form>