{% extends "base.html" %}
{% block content %}
<h3>Registered Tag List</h3>
<ul>
	{% for tag in object_list %}
	<li><a href="{{ tag.get_absolute_url }}">{{ tag }} ({{ tag.items.count }})</a></li>
	{% endfor %}
</ul>
<p><a href="/">&lt;&lt; Back to home</a></p>
{% endblock %}